"""Sphinx Carousel."""
__author__ = "Robpol86"
__license__ = "BSD-2-Clause"
__version__ = "1.1.0"
